==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/GroupVersionForDiscoveryFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface GroupVersionForDiscoveryFluent<A extends GroupVersionForDiscoveryFluent<A>> extends Fluent<A> {


    public String getGroupVersion();
    public A withGroupVersion(String groupVersion);
    public Boolean hasGroupVersion();
    public A withNewGroupVersion(StringBuilder arg1);
    public A withNewGroupVersion(int[] arg1,int arg2,int arg3);
    public A withNewGroupVersion(char[] arg1);
    public A withNewGroupVersion(StringBuffer arg1);
    public A withNewGroupVersion(byte[] arg1,int arg2);
    public A withNewGroupVersion(byte[] arg1);
    public A withNewGroupVersion(char[] arg1,int arg2,int arg3);
    public A withNewGroupVersion(byte[] arg1,int arg2,int arg3);
    public A withNewGroupVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewGroupVersion(String arg1);
    public String getVersion();
    public A withVersion(String version);
    public Boolean hasVersion();
    public A withNewVersion(StringBuilder arg1);
    public A withNewVersion(int[] arg1,int arg2,int arg3);
    public A withNewVersion(char[] arg1);
    public A withNewVersion(StringBuffer arg1);
    public A withNewVersion(byte[] arg1,int arg2);
    public A withNewVersion(byte[] arg1);
    public A withNewVersion(char[] arg1,int arg2,int arg3);
    public A withNewVersion(byte[] arg1,int arg2,int arg3);
    public A withNewVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewVersion(String arg1);
}

==> kubernetes-model-core-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/GroupVersionForDiscoveryFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface GroupVersionForDiscoveryFluent<A extends GroupVersionForDiscoveryFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getGroupVersion();
    public A withGroupVersion(String groupVersion);
    public Boolean hasGroupVersion();
    public A withNewGroupVersion(StringBuilder arg1);
    public A withNewGroupVersion(int[] arg1,int arg2,int arg3);
    public A withNewGroupVersion(char[] arg1);
    public A withNewGroupVersion(StringBuffer arg1);
    public A withNewGroupVersion(byte[] arg1,int arg2);
    public A withNewGroupVersion(byte[] arg1);
    public A withNewGroupVersion(char[] arg1,int arg2,int arg3);
    public A withNewGroupVersion(byte[] arg1,int arg2,int arg3);
    public A withNewGroupVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewGroupVersion(String arg1);
    public String getVersion();
    public A withVersion(String version);
    public Boolean hasVersion();
    public A withNewVersion(StringBuilder arg1);
    public A withNewVersion(int[] arg1,int arg2,int arg3);
    public A withNewVersion(char[] arg1);
    public A withNewVersion(StringBuffer arg1);
    public A withNewVersion(byte[] arg1,int arg2);
    public A withNewVersion(byte[] arg1);
    public A withNewVersion(char[] arg1,int arg2,int arg3);
    public A withNewVersion(byte[] arg1,int arg2,int arg3);
    public A withNewVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewVersion(String arg1);
}
